summaryrefslogtreecommitdiff
path: root/sal/inc
diff options
context:
space:
mode:
authorTakeshi Abe <tabe@fixedpoint.jp>2010-12-05 19:11:58 +0000
committerCaolán McNamara <caolanm@redhat.com>2010-12-06 09:16:29 +0000
commit36e2296bf8fae3c66a66eada3595cbb2628a4833 (patch)
treeea0857de290ed5b5874ec3f17d131fd61f827314 /sal/inc
parent1b11499074d855e34f40953898594035ca451c71 (diff)
Replace all occured, occurance etc.
Diffstat (limited to 'sal/inc')
-rw-r--r--sal/inc/osl/conditn.h2
-rw-r--r--sal/inc/osl/pipe_decl.hxx4
-rw-r--r--sal/inc/osl/process.h4
-rw-r--r--sal/inc/osl/socket.h16
-rw-r--r--sal/inc/osl/socket_decl.hxx14
-rw-r--r--sal/inc/rtl/bootstrap.h2
-rw-r--r--sal/inc/rtl/bootstrap.hxx2
-rw-r--r--sal/inc/rtl/instance.hxx6
-rw-r--r--sal/inc/rtl/tencinfo.h2
9 files changed, 26 insertions, 26 deletions
diff --git a/sal/inc/osl/conditn.h b/sal/inc/osl/conditn.h
index 1811bcdf2107..88478c377bf3 100644
--- a/sal/inc/osl/conditn.h
+++ b/sal/inc/osl/conditn.h
@@ -40,7 +40,7 @@ typedef void* oslCondition;
typedef enum {
osl_cond_result_ok, /* successful completion */
- osl_cond_result_error, /* error occured, check osl_getLastSocketError() for details */
+ osl_cond_result_error, /* error occurred, check osl_getLastSocketError() for details */
osl_cond_result_timeout, /* blocking operation timed out */
osl_cond_result_FORCE_EQUAL_SIZE = SAL_MAX_ENUM
} oslConditionResult;
diff --git a/sal/inc/osl/pipe_decl.hxx b/sal/inc/osl/pipe_decl.hxx
index c5d97e3d2914..54ccb93f5375 100644
--- a/sal/inc/osl/pipe_decl.hxx
+++ b/sal/inc/osl/pipe_decl.hxx
@@ -134,8 +134,8 @@ public:
/** Delivers a constant decribing the last error for the pipe system.
- @return ENONE if no error occured, invalid_PipeError if
- an unknown (unmapped) error occured, otherwise an enum describing the
+ @return ENONE if no error occurred, invalid_PipeError if
+ an unknown (unmapped) error occurred, otherwise an enum describing the
error.
*/
inline oslPipeError SAL_CALL getError() const;
diff --git a/sal/inc/osl/process.h b/sal/inc/osl/process.h
index 1c71a4fc5e02..9e3012a2fb71 100644
--- a/sal/inc/osl/process.h
+++ b/sal/inc/osl/process.h
@@ -69,7 +69,7 @@ typedef sal_uInt32 oslProcessExitCode;
typedef enum {
osl_Process_E_None, /* no error */
osl_Process_E_NotFound, /* image not found */
- osl_Process_E_TimedOut, /* timout occured */
+ osl_Process_E_TimedOut, /* timout occurred */
osl_Process_E_NoPermission, /* permission denied */
osl_Process_E_Unknown, /* unknown error */
osl_Process_E_InvalidError, /* unmapped error */
@@ -323,7 +323,7 @@ oslProcessError SAL_CALL osl_joinProcess(oslProcess Process);
@return
osl_Process_E_None on success
osl_Process_E_TimedOut waiting for the child process timed out
- osl_Process_E_Unknown an error occured or the parameter are invalid
+ osl_Process_E_Unknown an error occurred or the parameter are invalid
@see osl_executeProcess
*/
diff --git a/sal/inc/osl/socket_decl.hxx b/sal/inc/osl/socket_decl.hxx
index 7660075e3e8a..6376c1bc3613 100644
--- a/sal/inc/osl/socket_decl.hxx
+++ b/sal/inc/osl/socket_decl.hxx
@@ -277,7 +277,7 @@ namespace osl
You can specify a timeout-value in seconds/nanoseconds that denotes
how the operation will block if the Socket is not ready.
@return <code>sal_True</code> if read operations (recv, recvFrom, accept) on the Socket
- will NOT block; <code>sal_False</code> if it would block or if an error occured.
+ will NOT block; <code>sal_False</code> if it would block or if an error occurred.
@param pTimeout if 0, the operation will block without a timeout. Otherwise
the specified amout of time.
@@ -289,7 +289,7 @@ namespace osl
You can specify a timeout-value in seconds/nanoseconds that denotes
how the operation will block if the Socket is not ready.
@return <code>sal_True</code> if send operations (send, sendTo) on the Socket
- will NOT block; <code>sal_False</code> if it would block or if an error occured.
+ will NOT block; <code>sal_False</code> if it would block or if an error occurred.
@param pTimeout if 0, the operation will block without a timeout. Otherwise
the specified amout of time.
@@ -304,7 +304,7 @@ namespace osl
@return <code>sal_True</code> if OOB-request operations (recv with appropriate flags)
on the Socket will NOT block; <code>sal_False</code> if it would block or if
- an error occured.
+ an error occurred.
@param pTimeout if 0, the operation will block without a timeout. Otherwise
the specified amout of time.
@@ -320,7 +320,7 @@ namespace osl
<li> <code>osl_Socket_TypeRaw</code>
<li> <code>osl_Socket_TypeRdm</code>
<li> <code>osl_Socket_TypeSeqPacket</code>
- <li> <code>osl_invalid_SocketType</code>, if an error occured
+ <li> <code>osl_invalid_SocketType</code>, if an error occurred
</ul>
*/
inline oslSocketType SAL_CALL getType() const;
@@ -404,7 +404,7 @@ namespace osl
<li><code>osl_Socket_LevelTcp</code> : Level of Transmission Control Protocol
</ul>
@return The size of the attribute copied into pBuffer or -1 if an error
- occured.
+ occurred.
*/
inline sal_Int32 SAL_CALL getOption(
oslSocketOption Option,
@@ -488,8 +488,8 @@ namespace osl
/** returns a constant decribing the last error for the socket system.
- @return osl_Socket_E_NONE if no error occured, invalid_SocketError if
- an unknown (unmapped) error occured, otherwise an enum describing the
+ @return osl_Socket_E_NONE if no error occurred, invalid_SocketError if
+ an unknown (unmapped) error occurred, otherwise an enum describing the
error.
@see osl_getLastSocketError()
*/
diff --git a/sal/inc/rtl/bootstrap.h b/sal/inc/rtl/bootstrap.h
index 18e3b64e76e8..cd0507bef5df 100644
--- a/sal/inc/rtl/bootstrap.h
+++ b/sal/inc/rtl/bootstrap.h
@@ -218,7 +218,7 @@ void SAL_CALL rtl_bootstrap_expandMacros(
an arbitrary, non-NULL value
@param encoded
- non-NULL out parameter, receiving the given value with all occurences of
+ non-NULL out parameter, receiving the given value with all occurrences of
special characters ("$" and "\") escaped
@since UDK 3.2.9
diff --git a/sal/inc/rtl/bootstrap.hxx b/sal/inc/rtl/bootstrap.hxx
index 290bb1e38850..dca3e84ce4c8 100644
--- a/sal/inc/rtl/bootstrap.hxx
+++ b/sal/inc/rtl/bootstrap.hxx
@@ -150,7 +150,7 @@ namespace rtl
an arbitrary value
@return
- the given value, with all occurences of special characters ("$" and
+ the given value, with all occurrences of special characters ("$" and
"\") escaped
@since UDK 3.2.9
diff --git a/sal/inc/rtl/instance.hxx b/sal/inc/rtl/instance.hxx
index 2ef1a8d3853e..d4ee7cc7f68d 100644
--- a/sal/inc/rtl/instance.hxx
+++ b/sal/inc/rtl/instance.hxx
@@ -232,10 +232,10 @@ namespace {
Some comments:
For any instantiation of rtl_Instance, at most one call to a create method
- may occur in the program code: Each occurance of a create method within
+ may occur in the program code: Each occurrence of a create method within
the program code is supposed to return a fresh object instance on the
first call, and that same object instance on subsequent calls; but
- independent occurances of create methods are supposed to return
+ independent occurrences of create methods are supposed to return
independent object instances. Since there is a one-to-one correspondence
between object instances and instantiations of rtl_Instance, the
requirement should be clear. One measure to enforce the requirement is
@@ -245,7 +245,7 @@ namespace {
needs a funny "hand coded" prefix "rtl_" instead of a proper namespace
prefix like "::rtl::".
- A known problem with this template is when two occurences of calls to
+ A known problem with this template is when two occurrences of calls to
create methods with identical template arguments appear in one translation
unit. Those two places will share a single object instance. This can be
avoided by using different Init structs (see the above code samples) in
diff --git a/sal/inc/rtl/tencinfo.h b/sal/inc/rtl/tencinfo.h
index cccdd229eaaf..cc70d30423ed 100644
--- a/sal/inc/rtl/tencinfo.h
+++ b/sal/inc/rtl/tencinfo.h
@@ -104,7 +104,7 @@ typedef struct _rtl_TextEncodingInfo
ASCII control codes 0x00--1F are not included here, as they are used for
special purposes in some encodings.
- If an encoding has this property, it is easy to search for occurences of
+ If an encoding has this property, it is easy to search for occurrences of
ASCII characters within strings of this encoding---you do not need to
keep track whether a byte in the range 0x20--7F really represents an
ASCII character or rather is part of some multi-byte character.
diff --git a/sal/inc/osl/socket.h b/sal/inc/osl/socket.h
index fb2d32eb440e..f936102cdc43 100644
--- a/sal/inc/osl/socket.h
+++ b/sal/inc/osl/socket.h
@@ -195,7 +195,7 @@ typedef enum {
*/
typedef enum {
osl_Socket_Ok, /* successful completion */
- osl_Socket_Error, /* error occured, check osl_getLastSocketError() for details */
+ osl_Socket_Error, /* error occurred, check osl_getLastSocketError() for details */
osl_Socket_TimedOut, /* blocking operation timed out */
osl_Socket_Interrupted, /* blocking operation was interrupted */
osl_Socket_InProgress, /* nonblocking operation is in progress */
@@ -594,7 +594,7 @@ sal_Int32 SAL_CALL osl_sendToSocket(oslSocket Socket,
how long the operation will block if the Socket is not ready.
@return <code>sal_True</code> if read operations (recv, recvFrom, accept) on the Socket
- will NOT block; <code>sal_False</code> if it would block or if an error occured.
+ will NOT block; <code>sal_False</code> if it would block or if an error occurred.
@param Socket the Socket to perfom the operation on.
@param pTimeout if NULL, the operation will block without a timeout.
@@ -605,7 +605,7 @@ sal_Bool SAL_CALL osl_isReceiveReady(oslSocket Socket, const TimeValue* pTimeout
You can specify a timeout-value in seconds/microseconds that denotes
how long the operation will block if the Socket is not ready.
@return <code>sal_True</code> if send operations (send, sendTo) on the Socket
- will NOT block; <code>sal_False</code> if it would block or if an error occured.
+ will NOT block; <code>sal_False</code> if it would block or if an error occurred.
@param Socket the Socket to perfom the operation on.
@param pTimeout if NULL, the operation will block without a timeout. Otherwise
@@ -617,7 +617,7 @@ sal_Bool SAL_CALL osl_isSendReady(oslSocket Socket, const TimeValue* pTimeout);
You can specify a timeout-value in seconds/microseconds that denotes
how long the operation will block if the Socket has no pending OOB data.
@return <code>sal_True</code> if OOB-request operations (recv with appropriate flags)
- on the Socket will NOT block; <code>sal_False</code> if it would block or if an error occured.
+ on the Socket will NOT block; <code>sal_False</code> if it would block or if an error occurred.
@param Socket the Socket to perfom the operation on.
@param pTimeout if NULL, the operation will block without a timeout.
@@ -717,7 +717,7 @@ sal_Bool SAL_CALL osl_shutdownSocket(oslSocket Socket,
@param BufferSize contains the length of the Buffer.
- @return -1 if an error occured or else the size of the data copied into
+ @return -1 if an error occurred or else the size of the data copied into
pBuffer.
@see osl_setSocketOption()
*/
@@ -778,7 +778,7 @@ sal_Bool SAL_CALL osl_isNonBlockingMode(oslSocket Socket);
<li> osl_Socket_TypeRaw
<li> osl_Socket_TypeRdm
<li> osl_Socket_TypeSeqPacket
- <li> osl_invalid_SocketType, if an error occured
+ <li> osl_invalid_SocketType, if an error occurred
</ul>
*/
@@ -790,9 +790,9 @@ oslSocketType SAL_CALL osl_getSocketType(oslSocket Socket);
void SAL_CALL osl_getLastSocketErrorDescription(oslSocket Socket, rtl_uString **strError);
/** returns a constant decribing the last error for the socket system.
- @return <code>osl_Socket_E_NONE</code> if no error occured,
+ @return <code>osl_Socket_E_NONE</code> if no error occurred,
<code>osl_invalid_SocketError</code> if an unknown (unmapped)
- error occured, otherwise an enum describing the error.
+ error occurred, otherwise an enum describing the error.
*/
oslSocketError SAL_CALL osl_getLastSocketError(oslSocket Socket);